@@ -10,6 +10,10 @@ from gopup.index.index_baidu import (
     baidu_search_index,
     baidu_info_index,
     baidu_media_index,
+    baidu_interest_index,
+    baidu_gender_index,
+    baidu_age_index,
+    baidu_atlas_index
 )
 
 """
@@ -118,6 +122,16 @@ from gopup.movie.movie import (
     realtime_artist_flow
 )
 
+
+"""
+高校数据
+"""
+from gopup.life.university import (
+    university,
+    adult_university
+)
+
+
 """
 专业版接口
 """
